@@ -1,5 +1,20 @@
 import pandas as pd
 import numpy as np
+import os, uuid
+from vulcan_athena.mirandareporting.setup import CONNECTION_STRING
+from azure.storage.blob import BlobServiceClient, BlobClient, ContainerClient, __version__
+
+CONTAINER_NAME = "container-test-output"
+
+
+def blob_writer(myobj, mystring):
+    BLOB_NAME = "./" + mystring
+
+    blob = BlobClient.from_connection_string(conn_str=CONNECTION_STRING, container_name=CONTAINER_NAME,
+                                             blob_name=BLOB_NAME)
+
+    with open(myobj, "rb") as data:
+        blob.upload_blob(data, overwrite=True)
 
 
 def base_table(data, year, month, status=''):
@@ -50,7 +65,8 @@ def dashboard_files_new(master_dict, inventory_dict, deal_dict, dict_df, year):
                 df_list.append(base_table(master_dict[month][status].fillna(0), year, month, status))
 
     sales_df = pd.concat(df_list)
-    sales_df.to_csv(f'base_agg_tables_tem/{year}_' + 'Sales_Summary' + '.csv')
+    # sales_df.to_csv(f'base_agg_tables_tem/{year}_' + 'Sales_Summary' + '.csv')
+    blob_writer(sales_df, str(year) + 'Sales_Summary' + '.csv')
 
     # Business Line Information
     df_list = []
@@ -78,7 +94,8 @@ def dashboard_files_new(master_dict, inventory_dict, deal_dict, dict_df, year):
                 df_list.append(base_table_bus_lines(commission, year, month, status))
 
     sales_df = pd.concat(df_list, sort=False)
-    sales_df.to_csv(f'base_agg_tables_tem/{year}_' + 'Sales' + '.csv')
+    # sales_df.to_csv(f'base_agg_tables_tem/{year}_' + 'Sales' + '.csv')
+    blob_writer(sales_df, str(year) + 'Sales' + '.csv')
 
     # Inventory Information
     df_list = []
@@ -87,7 +104,8 @@ def dashboard_files_new(master_dict, inventory_dict, deal_dict, dict_df, year):
         df_list.append(base_table(inventory_dict[month].fillna(0), year, month))
 
     sales_df = pd.concat(df_list, sort=False)
-    sales_df.to_csv(f'base_agg_tables_tem/{year}_' + 'Inventory' + '.csv')
+    # sales_df.to_csv(f'base_agg_tables_tem/{year}_' + 'Inventory' + '.csv')
+    blob_writer(sales_df, str(year) + 'Inventory' + '.csv')
 
     # Deal Ref information
     df_list = []
@@ -98,7 +116,8 @@ def dashboard_files_new(master_dict, inventory_dict, deal_dict, dict_df, year):
                 df_list.append(base_table(deal_dict[month][status].fillna(0), year, month, status))
 
     sales_df = pd.concat(df_list)
-    sales_df.to_csv(f'base_agg_tables_tem/{year}_' + 'DealRef_Summary' + '.csv')
+    # sales_df.to_csv(f'base_agg_tables_tem/{year}_' + 'DealRef_Summary' + '.csv')
+    blob_writer(sales_df, str(year) + 'DealRef_Summary' + '.csv')
 
     # Deal Ref Business Line Information
     df_list = []
@@ -126,4 +145,5 @@ def dashboard_files_new(master_dict, inventory_dict, deal_dict, dict_df, year):
                 df_list.append(base_table_bus_lines(commission, year, month, status))
 
     sales_df = pd.concat(df_list, sort=False)
-    sales_df.to_csv(f'base_agg_tables_tem/{year}_' + 'DealRef_Sales_Summary' + '.csv')
+    # sales_df.to_csv(f'base_agg_tables_tem/{year}_' + 'DealRef_Sales_Summary' + '.csv')
+    blob_writer(sales_df, str(year) + 'DealRef_Summary' + '.csv')
